=======
History
=======

0.1.0 (2016-11-25)
------------------

* First release on PyPI.

0.2.0 (2016-11-28)
------------------

* Make batcher size/time limit configurable.
* Added test cases and documentation.
